@@ -74,7 +74,8 @@ coding_dict = {
 
 if datadir == '@' + "datadir" + "@":
 	datadir = os.getcwd ()
-
+	bindir =  os.getcwd ()
+	
 sys.path.append (datadir)
 
 import afm
@@ -96,6 +97,10 @@ except:
 	def _ (s):
 		return s
 
+def shell_escape_filename (str):
+	str = re.sub ('([\'" ])', r'\\\1', str)
+	return str
+
 def identify (port):
 	port.write ('%s %s\n' % (program_name, program_version))
 
@@ -301,7 +306,7 @@ def find_file (nm):
 		except IOError:
 			pass
 
-	p = popen ('kpsewhich %s' % nm).read ()[:-1]
+	p = popen ('kpsewhich %s' % shell_escape_filename (nm)).read ()[:-1]
 
 	# urg. Did I do this ?
 	if dos_kpath_p:
@@ -380,7 +385,7 @@ def make_pbm (filename, outname, char_number):
 	""" Extract bitmap from the PK file FILENAME (absolute) using `gf2pbm'.
 	Return FALSE if the glyph is not valid.
 	"""
-	
+
 	command = "%s/gf2pbm -n %d -o %s %s" % (bindir, char_number, outname, filename)
 	status = system (command, ignore_error = 1)
 	return (status == 0)
@@ -893,7 +898,7 @@ def assemble_font (fontname, format, is_raw):
     outname = fontname + ext
 
     progress (_ ("Assembling raw font to `%s'... ") % outname)
-    system ('t1asm %s mftrace.t1asm %s' % (asm_opt, outname))
+    system ('t1asm %s mftrace.t1asm %s' % (asm_opt, shell_escape_filename (outname)))
     progress ('\n')
     return outname
 
@@ -918,7 +923,7 @@ def make_outputs (fontname, formats, encoding):
 			simplify_cmd = 'RoundToInt ();'
 		generate_cmds = ''
 		for f in formats:
-			generate_cmds += 'Generate("%s");' % (filename  + '.' + f)
+			generate_cmds += 'Generate("%s");' % (fontname  + '.' + f)
 
 		if simplify_p:
 			simplify_cmd ='''SelectAll ();
@@ -928,7 +933,7 @@ Simplify ();
 %(simplify_cmd)s
 AutoHint ();''' % vars()
 
-		open ('to-ttf.pe', 'w').write ('''#!/usr/bin/env %(ff_command)s
+		pe_script = ('''#!/usr/bin/env %(ff_command)s
 Open ($1);
 MergeKern($2);
 %(simplify_cmd)s
@@ -936,8 +941,11 @@ MergeKern($2);
 Quit (0);
 ''' % vars())
 
+		open ('to-ttf.pe', 'w').write (pe_script)
+		if verbose_p:
+			print 'Fontforge script', pe_script
 		system ("%s -script to-ttf.pe %s %s" % (ff_command,
-			    (raw_name), tfmfile))
+			    shell_escape_filename (raw_name), shell_escape_filename (tfmfile)))
 	else:
 		t1_path = ''
 	
@@ -1340,7 +1348,7 @@ for filename in files:
 		tfmfile = find_file (basename + '.tfm')
 
 	if not tfmfile:
-		tfmfile = popen ("mktextfm %s 2>/dev/null" % basename).read ()
+		tfmfile = popen ("mktextfm %s 2>/dev/null" % shell_escape_filename (basename)).read ()
 		if tfmfile:
 			tfmfile = tfmfile[:-1]
 
